@@ -12,6 +12,8 @@ def _screenMainLoop(s):
     s.getTerminalSize()
     s.refresh(f=True)
     resizeCheck = int(round(time.time() * 1000))
+    msg=[]
+
     while True:
         if int(round(time.time() * 1000)) - resizeCheck > 1000:
             s.getTerminalSize()
@@ -21,17 +23,16 @@ def _screenMainLoop(s):
             msg = s.q.get(timeout=0.5)
         except Empty:
             s.refresh()
-
-        if msg and msg[0] == 'Q':
-            return
-        elem = s._getElem(msg[0])
-        if elem:
-            elem.receive(msg[1:])
-            s.refresh()
+        if  isinstance(msg, list) and len(msg) > 0:
+            if msg[0] == 'Q':
+                return
+            elem = s.getElem(msg[0])
+            if elem:
+                elem.receive(msg[1:])
+                s.refresh()
 
 
-
-class server:
+class Server:
     def __init__(self):
         self.q = Queue()
         self.state = {}
@@ -40,23 +41,23 @@ class server:
         self.rows = 20
         self.columns = 80
         self.getTerminalSize()
-
+        self.lastRefresh = 0
 
     def start(self):
         self._p = Process(target=_screenMainLoop, args=(self,))
         self._p.start()
 
     def buildBuffer(self, top=None, bottom=None, height=None, color=249, background=235):
-        id = len(self.elems)
+        elem_id = len(self.elems)
         element = bufferServer(top=top, bottom=bottom, height=height, color=color, background=background)
-        self.elems[id] = element
-        return buffer(self.q, id)
+        self.elems[elem_id] = element
+        return buffer(self.q, elem_id)
 
-    def buildLine(self,top=None, bottom=None, pattern=[''], background=40, color=50):
-        id = len(self.elems)
+    def buildLine(self, top=None, bottom=None, pattern=[''], background=40, color=50):
+        elem_id = len(self.elems)
         element = lineServer(top=top, bottom=bottom, pattern=pattern, background=background, color=color)
-        self.elems[id] = element
-        return line(self.q, id, element.variables)
+        self.elems[elem_id] = element
+        return line(self.q, elem_id, element.variables)
 
     def _getElem(self, elem):
         if elem in self.elems:
@@ -64,6 +65,10 @@ class server:
         return None
 
     def refresh(self, f=False):
+        millis = int(round(time.time() * 1000))
+        if millis - self.lastRefresh < 20:
+            self.lastRefresh = int(round(time.time() * 1000))
+            return
         if f:
             print("\u001b[2J")
         for v in self.elems.values():
@@ -106,9 +111,8 @@ def bufferPrinter(bs: buffer):
         time.sleep(1.1)
 
 
-
 if __name__ == "__main__":
-    ss = server()
+    ss = Server()
     l1 = ss.buildLine(top=1, pattern=[" Main Pattern : ", SR(background=240), "  ",Vstr("v"),"  "], background=52, color=207)
     l2 = ss.buildLine(top=2, pattern=[" Main Pattern  ", SR(background=240), Vint("count:>8")," ", SR(background=245), Vint("total:>8")," "], background=55, color=207)
     upperConsole = ss.buildBuffer(top=3, height=20)
@@ -117,8 +121,6 @@ if __name__ == "__main__":
     ss.buildLine(bottom=1, background=24)
     ss.start()
 
-
-
     pr = [Process(target=linePrinter, args=[l1]),
           Process(target=linePrinter2, args=[l2]),
           Process(target=bufferPrinter, args=[upperConsole]),
